==> postfinancecheckout-java-sdk-6.0.1-sources.jar: ch/postfinance/sdk/model/CardAuthenticationResponse.java <==
/**
* PostFinance Checkout SDK
*
* This library allows to interact with the PostFinance Checkout payment service.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/


package ch.postfinance.sdk.model;

import java.util.Objects;
import java.util.Arrays;
import io.swagger.annotations.ApiModel;
import java.util.*;
import java.time.OffsetDateTime;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * 
 */
public enum CardAuthenticationResponse {
  
  ENROLLMENT_VERIFICATION_ERROR("ENROLLMENT_VERIFICATION_ERROR"),
  
  NOT_ENROLLED("NOT_ENROLLED"),
  
  AUTHENTICATION_ERROR("AUTHENTICATION_ERROR"),
  
  AUTHENTICATION_NOT_REQUIRED("AUTHENTICATION_NOT_REQUIRED"),
  
  FULLY_AUTHENTICATED("FULLY_AUTHENTICATED");

  private String value;

  CardAuthenticationResponse(String value) {
    this.value = value;
  }

  @JsonValue
  public String getValue() {
    return value;
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static CardAuthenticationResponse fromValue(String text) {
    for (CardAuthenticationResponse b : CardAuthenticationResponse.values()) {
      if (String.valueOf(b.value).equals(text)) {
        return b;
      }
    }
    return null;
  }
}

==> postfinancecheckout-java-sdk-6.2.0-sources.jar: ch/postfinance/sdk/model/CardAuthenticationResponse.java <==
/**
* PostFinance Checkout SDK
*
* This library allows to interact with the PostFinance Checkout payment service.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/


package ch.postfinance.sdk.model;

import java.util.Objects;
import java.util.Arrays;
import io.swagger.annotations.ApiModel;
import java.util.*;
import java.time.OffsetDateTime;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * 
 */
public enum CardAuthenticationResponse {
  
  FULLY_AUTHENTICATED("FULLY_AUTHENTICATED"),
  
  AUTHENTICATION_NOT_REQUIRED("AUTHENTICATION_NOT_REQUIRED"),
  
  NOT_ENROLLED("NOT_ENROLLED"),
  
  ENROLLMENT_ERROR("ENROLLMENT_ERROR"),
  
  AUTHENTICATION_ERROR("AUTHENTICATION_ERROR");

  private String value;

  CardAuthenticationResponse(String value) {
    this.value = value;
  }

  @JsonValue
  public String getValue() {
    return value;
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static CardAuthenticationResponse fromValue(String text) {
    for (CardAuthenticationResponse b : CardAuthenticationResponse.values()) {
      if (String.valueOf(b.value).equals(text)) {
        return b;
      }
    }
    return null;
  }
}
